##
##  wget.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         wget
Summary:      Batch Client for HTTP and FTP Protocol
URL:          http://wget.dotsrc.org/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Web
License:      GPL
Version:      2.1.0
Release:      20230903

#   list of sources
Source0:      http://ftp.gnu.org/gnu/wget/wget2-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  openssl, libidn2
PreReq:       openssl, libidn2

%description
    GNU wget is a freely available network utility to retrieve files
    from the World Wide Web using HTTP and FTP, the two most widely used
    Internet protocols. It works non-interactively, thus enabling work
    in the background after having logged off.

%track
    prog wget = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/wget/
        regex     = wget2-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n wget2-%{version}

%build
    %{l_shtool} subst \
        -e 's;/usr/local/etc;%{l_prefix}/etc/wget;g' \
        doc/sample.wgetrc \
        doc/sample.wgetrc.munged_for_texi_inclusion \
        doc/wget.texi
    (   echo "ac_cv_header_uuid_uuid_h=no"
        echo "ac_cv_header_uuid_h=no"
    ) >config.cache
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    MAKEINFO="true" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
        --mandir=%{l_prefix}/man \
        --sysconfdir=%{l_prefix}/etc/wget \
        --with-ssl=openssl \
        --without-libpsl \
        --without-libidn \
        --without-brotlidec \
        --with-libidn2 \
        --disable-shared \
        --disable-nls
    %{l_make} %{l_mflags -O}

%install
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/wget
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/bin/wget2_noinstall >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/charset.alias >/dev/null 2>&1 || true
    ln  $RPM_BUILD_ROOT%{l_prefix}/bin/wget2 \
        $RPM_BUILD_ROOT%{l_prefix}/bin/wget
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

